import { LanguageModelV1, LanguageModelV1CallOptions, LanguageModelV1FunctionToolCall, LanguageModelV1FinishReason, LanguageModelV1CallWarning, LanguageModelV1ProviderMetadata, LanguageModelV1Source, LanguageModelV1LogProbs, LanguageModelV1StreamPart, EmbeddingModelV1, ProviderV1 } from '@ai-sdk/provider';

declare class HFTransformersjsCompletionLanguageModelOpenAICompatible implements LanguageModelV1 {
    readonly specificationVersion = "v1";
    readonly modelId: string;
    readonly settings: Record<string, unknown>;
    readonly provider: string;
    readonly defaultObjectGenerationMode = "json";
    private config;
    private pipelineInstance?;
    constructor(modelId: string, settings: Record<string, unknown>, config: {
        provider: string;
        apiKey?: string;
    });
    private ensurePipeline;
    doGenerate(options: LanguageModelV1CallOptions): PromiseLike<{
        text?: string;
        reasoning?: string | Array<{
            type: 'text';
            text: string;
            signature?: string;
        } | {
            type: 'redacted';
            data: string;
        }>;
        toolCalls?: Array<LanguageModelV1FunctionToolCall>;
        finishReason: LanguageModelV1FinishReason;
        usage: {
            promptTokens: number;
            completionTokens: number;
        };
        rawCall: {
            rawPrompt: unknown;
            rawSettings: Record<string, unknown>;
        };
        rawResponse?: {
            headers?: Record<string, string>;
            body?: unknown;
        };
        request?: {
            body?: string;
        };
        response?: {
            id?: string;
            timestamp?: Date;
            modelId?: string;
        };
        warnings?: LanguageModelV1CallWarning[];
        providerMetadata?: LanguageModelV1ProviderMetadata;
        sources?: LanguageModelV1Source[];
        logprobs?: LanguageModelV1LogProbs;
    }>;
    private doGenerateImpl;
    doStream(options: LanguageModelV1CallOptions): PromiseLike<{
        stream: ReadableStream<LanguageModelV1StreamPart>;
        rawCall: {
            rawPrompt: unknown;
            rawSettings: Record<string, unknown>;
        };
        rawResponse?: {
            headers?: Record<string, string>;
        };
        request?: {
            body?: string;
        };
        warnings?: LanguageModelV1CallWarning[];
    }>;
    private doStreamImpl;
    private getPromptText;
}

declare class HFTransformersjsChatLanguageModel implements LanguageModelV1 {
    readonly specificationVersion = "v1";
    readonly modelId: string;
    readonly settings: Record<string, unknown>;
    readonly provider: string;
    readonly defaultObjectGenerationMode = "json";
    private config;
    private pipelineInstance?;
    constructor(modelId: string, settings: Record<string, unknown>, config: {
        provider: string;
        apiKey?: string;
    });
    private ensurePipeline;
    doGenerate(options: LanguageModelV1CallOptions): PromiseLike<{
        text?: string;
        reasoning?: string | Array<{
            type: 'text';
            text: string;
            signature?: string;
        } | {
            type: 'redacted';
            data: string;
        }>;
        toolCalls?: Array<LanguageModelV1FunctionToolCall>;
        finishReason: LanguageModelV1FinishReason;
        usage: {
            promptTokens: number;
            completionTokens: number;
        };
        rawCall: {
            rawPrompt: unknown;
            rawSettings: Record<string, unknown>;
        };
        rawResponse?: {
            headers?: Record<string, string>;
            body?: unknown;
        };
        request?: {
            body?: string;
        };
        response?: {
            id?: string;
            timestamp?: Date;
            modelId?: string;
        };
        warnings?: LanguageModelV1CallWarning[];
        providerMetadata?: LanguageModelV1ProviderMetadata;
        sources?: LanguageModelV1Source[];
        logprobs?: LanguageModelV1LogProbs;
    }>;
    private doGenerateImpl;
    private convertPromptToString;
    doStream(options: LanguageModelV1CallOptions): PromiseLike<{
        stream: ReadableStream<LanguageModelV1StreamPart>;
        rawCall: {
            rawPrompt: unknown;
            rawSettings: Record<string, unknown>;
        };
        rawResponse?: {
            headers?: Record<string, string> | undefined;
        } | undefined;
        request?: {
            body: string;
        };
        warnings?: LanguageModelV1CallWarning[];
    }>;
    private doStreamImplementation;
}

declare class HFTransformersjsCompletionLanguageModel implements LanguageModelV1 {
    readonly specificationVersion = "v1";
    readonly modelId: string;
    readonly settings: Record<string, unknown>;
    readonly provider: string;
    readonly defaultObjectGenerationMode = "json";
    private config;
    private pipelineInstance?;
    constructor(modelId: string, settings: Record<string, unknown>, config: {
        provider: string;
        apiKey?: string;
    });
    private ensurePipeline;
    doGenerate(options: LanguageModelV1CallOptions): PromiseLike<{
        text?: string;
        reasoning?: string | Array<{
            type: 'text';
            text: string;
            signature?: string;
        } | {
            type: 'redacted';
            data: string;
        }>;
        toolCalls?: Array<LanguageModelV1FunctionToolCall>;
        finishReason: LanguageModelV1FinishReason;
        usage: {
            promptTokens: number;
            completionTokens: number;
        };
        rawCall: {
            rawPrompt: unknown;
            rawSettings: Record<string, unknown>;
        };
        rawResponse?: {
            headers?: Record<string, string>;
            body?: unknown;
        };
        request?: {
            body?: string;
        };
        response?: {
            id?: string;
            timestamp?: Date;
            modelId?: string;
        };
        warnings?: LanguageModelV1CallWarning[];
        providerMetadata?: LanguageModelV1ProviderMetadata;
        sources?: LanguageModelV1Source[];
        logprobs?: LanguageModelV1LogProbs;
    }>;
    private doGenerateImpl;
    doStream(options: LanguageModelV1CallOptions): PromiseLike<{
        stream: ReadableStream<LanguageModelV1StreamPart>;
        rawCall: {
            rawPrompt: unknown;
            rawSettings: Record<string, unknown>;
        };
        rawResponse?: {
            headers?: Record<string, string>;
        };
        request?: {
            body?: string;
        };
        warnings?: LanguageModelV1CallWarning[];
    }>;
    private doStreamImpl;
    private getPromptText;
}

type EmbeddingModelV1Embedding = number[];
declare class HFTransformersjsEmbeddingModel implements EmbeddingModelV1<string> {
    readonly specificationVersion = "v1";
    readonly modelId: string;
    readonly settings: Record<string, unknown>;
    readonly provider: string;
    readonly supportsParallelCalls: boolean;
    private config;
    private pipelineInstance?;
    constructor(modelId: string, settings: Record<string, unknown>, config: {
        provider: string;
        apiKey?: string;
    });
    get maxEmbeddingsPerCall(): number;
    private ensurePipeline;
    private extractVectorsFromOutput;
    doEmbed(options: {
        values: string[];
        headers?: Record<string, string>;
        abortSignal?: AbortSignal;
    }): Promise<{
        embeddings: EmbeddingModelV1Embedding[];
        usage?: {
            tokens: number;
        };
        rawResponse?: {
            headers?: Record<string, string>;
        };
    }>;
}

interface HFTransformersjsProvider<CHAT_MODEL_IDS extends string = string, COMPLETION_MODEL_IDS extends string = string, EMBEDDING_MODEL_IDS extends string = string> extends ProviderV1 {
    (modelId: CHAT_MODEL_IDS, settings?: Record<string, unknown>): LanguageModelV1;
    languageModel(modelId: CHAT_MODEL_IDS, settings?: Record<string, unknown>): LanguageModelV1;
    chatModel(modelId: CHAT_MODEL_IDS, settings?: Record<string, unknown>): LanguageModelV1;
    completionModel(modelId: COMPLETION_MODEL_IDS, settings?: Record<string, unknown>): LanguageModelV1;
    textEmbeddingModel(modelId: EMBEDDING_MODEL_IDS, settings?: Record<string, unknown>): EmbeddingModelV1<string>;
}
interface HFTransformersjsProviderSettings {
    /**
     * Provider name.
     */
    name: string;
    /**
     * API key for authenticating with HuggingFace, if required.
     */
    apiKey?: string;
}
declare function createHFTransformersjs<CHAT_MODEL_IDS extends string, COMPLETION_MODEL_IDS extends string, EMBEDDING_MODEL_IDS extends string>(options: HFTransformersjsProviderSettings): HFTransformersjsProvider<CHAT_MODEL_IDS, COMPLETION_MODEL_IDS, EMBEDDING_MODEL_IDS>;

declare class HFTransformersjsChatLanguageModelOpenAICompatible implements LanguageModelV1 {
    readonly specificationVersion = "v1";
    readonly modelId: string;
    readonly settings: Record<string, unknown>;
    readonly provider: string;
    readonly defaultObjectGenerationMode = "json";
    private config;
    private pipelineInstance?;
    constructor(modelId: string, settings: Record<string, unknown>, config: {
        provider: string;
        apiKey?: string;
    });
    private ensurePipeline;
    doGenerate(options: LanguageModelV1CallOptions): PromiseLike<{
        text?: string;
        reasoning?: string | Array<{
            type: 'text';
            text: string;
            signature?: string;
        } | {
            type: 'redacted';
            data: string;
        }>;
        toolCalls?: Array<LanguageModelV1FunctionToolCall>;
        finishReason: LanguageModelV1FinishReason;
        usage: {
            promptTokens: number;
            completionTokens: number;
        };
        rawCall: {
            rawPrompt: unknown;
            rawSettings: Record<string, unknown>;
        };
        rawResponse?: {
            headers?: Record<string, string>;
            body?: unknown;
        };
        request?: {
            body?: string;
        };
        response?: {
            id?: string;
            timestamp?: Date;
            modelId?: string;
        };
        warnings?: LanguageModelV1CallWarning[];
        providerMetadata?: LanguageModelV1ProviderMetadata;
        sources?: LanguageModelV1Source[];
        logprobs?: LanguageModelV1LogProbs;
    }>;
    private doGenerateImpl;
    doStream(options: LanguageModelV1CallOptions): PromiseLike<{
        stream: ReadableStream<LanguageModelV1StreamPart>;
        rawCall: {
            rawPrompt: unknown;
            rawSettings: Record<string, unknown>;
        };
        rawResponse?: {
            headers?: Record<string, string> | undefined;
        } | undefined;
        request?: {
            body: string;
        };
        warnings?: LanguageModelV1CallWarning[];
    }>;
    private doStreamImplementation;
    private convertPromptToString;
}

export { HFTransformersjsChatLanguageModel, HFTransformersjsChatLanguageModelOpenAICompatible, HFTransformersjsCompletionLanguageModel, HFTransformersjsCompletionLanguageModelOpenAICompatible, HFTransformersjsEmbeddingModel, type HFTransformersjsProvider, type HFTransformersjsProviderSettings, createHFTransformersjs };
